ErrorHandling class

Constructors

ErrorHandling()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getMapValue({required String key, required Map<String, dynamic> map}) → dynamic
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

charAtFirstToCaps({required dynamic char, required String safename}) → String
convertDataType({required dynamic dataType, required dynamic value}) → dynamic
encodeDataTypeForDb({required dynamic value}) → dynamic
getContainsKey({required Map<String?, dynamic> detail, required String? inputKey}) → String
getFileName({required dynamic file}) → String
getKeyName(dynamic value) → String
intNull({required dynamic value}) → dynamic
isBool({required dynamic value}) → dynamic
toLowerCase(dynamic value) → String
toUpperCase(dynamic value) → String