OcrController class

Constructors

OcrController()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

gstImageOcrMethod({required Map<String, dynamic> gstImageOcrParam}) → Future<List>
gstNoVerifyMethod({required Map<String, dynamic> gstNoVerifyParam}) → Future<List>
panImageOcrMethod({required Map<String, dynamic> panImageOcrParam}) → Future<List>
panNoVerifyMethod({required Map<String, dynamic> panNoVerifyParam}) → Future<List>