SharedPreferenceHelper class

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

clearSharedPreference() → Future<void>
deleteStringValueByKey(String key) → dynamic
getBoolValueFromKey(String key) → Future<bool>
getBunchDataFromSp({required Map<String, Type> data}) → Future<Map<String, dynamic>>
getIntValueFromKey(String key) → Future<int>
getStringValueFromKey(String key) → Future<String>
setBoolValueByKey({required String key, required bool value}) → dynamic
setBunchDataToSp({required Map<String, dynamic> data}) → dynamic
setIntValueByKey({required String key, required int value}) → dynamic
setStringValueByKey({required String key, required String value}) → dynamic