GstVerificationModel class

Constructors

GstVerificationModel({required String gstNo, required GstDetails gstDetails, dynamic gstResponse, required String projectName, required String userId, required String username, dynamic changeRequest})
GstVerificationModel.fromJson(Map<String, dynamic> json)
factory

Properties

changeRequest ↔ dynamic
getter/setter pair
gstDetails ↔ GstDetails
getter/setter pair
gstNo ↔ String
getter/setter pair
gstResponse ↔ dynamic
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
projectName ↔ String
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
userId ↔ String
getter/setter pair
username ↔ String
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited