PanDetails class

Constructors

PanDetails({required String clientId, required String panNumber, required String fullName, required String category})
PanDetails.fromJson(Map<String, dynamic> json)
factory

Properties

category ↔ String
getter/setter pair
clientId ↔ String
getter/setter pair
fullName ↔ String
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
panNumber ↔ String
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited