ColorFile class

Constructors

ColorFile()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

backGrey ↔ Color
getter/setter pair
baseColor ↔ Color
getter/setter pair
baseColor2 ↔ Color
getter/setter pair
baseColordark ↔ Color
getter/setter pair
baseColorlight ↔ Color
getter/setter pair
baseGreyDark ↔ Color
getter/setter pair
lightColor ↔ Color
getter/setter pair
primaryColor ↔ Color
getter/setter pair
textGrey2 ↔ Color
getter/setter pair